@@ -43,15 +43,15 @@ class MyTreeWidget : public QTreeWidget
 
 public:
 
-    explicit MyTreeWidget(QWidget* const parent = 0);
-    ~MyTreeWidget();
+    explicit MyTreeWidget(QWidget* const parent = nullptr);
+    ~MyTreeWidget() override;
 
 protected:
 
 //     void mousePressEvent(QMouseEvent* event);
 //     void mouseMoveEvent(QMouseEvent* event);
-    void startDrag(Qt::DropActions supportedActions);
-    virtual QMimeData* mimeData(const QList<QTreeWidgetItem*> items) const;
+    void startDrag(Qt::DropActions supportedActions) override;
+    QMimeData* mimeData(const QList<QTreeWidgetItem*> items) const override;
     virtual QMimeData* mimeData(const QModelIndexList items)         const;
 
 private:
